#
# spec file for package python-gear
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-gear
Version:        0.16.0
Release:        3.4
Summary:        Pure Python Async Gear Protocol Library
License:        Apache-2.0
URL:            https://opendev.org/opendev/gear
Source:         https://files.pythonhosted.org/packages/source/g/gear/gear-%{version}.tar.gz
BuildRequires:  %{python_module extras}
BuildRequires:  %{python_module fixtures >= 0.3.12}
BuildRequires:  %{python_module pbr >= 1.8.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyOpenSSL}
BuildRequires:  %{python_module python-daemon >= 2.0.4}
BuildRequires:  %{python_module python-subunit}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.5.2}
BuildRequires:  %{python_module testrepository >= 0.0.13}
BuildRequires:  %{python_module testresources}
BuildRequires:  %{python_module testscenarios}
BuildRequires:  %{python_module testtools >= 0.9.27}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-extras
Requires:       python-pbr >= 1.8.0
Requires:       python-python-daemon >= 2.0.4
Requires:       python-six >= 1.5.2
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
A pure-Python asynchronous library to interface with Gearman.

%prep
%setup -q -n gear-%{version}
%if 0%{?sle_version} <= 150600
# Remove project url in setup.cfg, this conf fails with old python
sed -i '9,13d' setup.cfg
%endif

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/geard

%check
%pyunittest discover -v

%post
%python_install_alternative geard

%postun
%python_uninstall_alternative geard

%files %{python_files}
%license LICENSE
%doc README.rst ChangeLog AUTHORS
%{python_sitelib}/gear
%{python_sitelib}/gear-%{version}.dist-info
%python_alternative %{_bindir}/geard

%changelog
* Wed Sep 25 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update URL.
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Mon May  6 2024 Daniel Garcia <daniel.garcia@suse.com>
- Enable tests again,
  https://storyboard.openstack.org/#!/story/2009250 is solved.
- Fix build for Backports with python 3.6, bsc#1222933
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update to 0.16.0
  * Merge "Update the docker image to python3.9 and buster"
  * Fix python3.9 testing
  * Update the docker image to python3.9 and buster
  * Overhaul package metadata and contributor info
  * Add libffi header dependency
  * Update testing to Python 3.9 and linters
  * Create SSL context using PROTOCOL_TLS, fallback to highest supported version
  * Merge "wakeConnections: Randomize connections before scanning them"
  * Merge "Move handleDisconnect into BaseClientServer"
  * Merge "remove unicode from code"
  * Merge "Modify connection timeout process"
  * wakeConnections: Randomize connections before scanning them
  * Added Docker image builds
  * remove unicode from code
  * Merge "Bump crypto requirement to accomodate security standards"
  * use python3 as context for build-python-release
  * Bump crypto requirement to accomodate security standards
  * Move handleDisconnect into BaseClientServer
  * Revert "Add BSD/Darwin support."
  * Merge "Ignore keepalive on unsupported platforms"
  * Merge "Add BSD/Darwin support."
* Fri Sep 24 2021 Matej Cepl <mcepl@suse.com>
- Switch off the test suite, because of https://storyboard.openstack.org/#!/story/2009250
* Thu Mar  5 2020 pgajdos@suse.com
- version update to 0.15.1
  * packaging: updated project urls
  * Ignore keepalive on unsupported platforms
  * Add in-repo zuul config
  * Fix documentation builds
* Fri Jul 26 2019 pgajdos@suse.com
- version update to 0.14.0
  * Add support for server name indication
  * OpenDev Migration Patch
* Thu Mar 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.13.0:
  * prefer ipv6 for listen addrs
  * add support for keepalive to client
- Execute tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Oct 30 2018 Dirk Mueller <dmueller@suse.com>
- update to 0.12.0:
  * Add --listen-address flag to geard
  * Build universal wheels
  * Automatically send GRAB\_JOB after CAN\_DO
* Mon Mar 26 2018 tbechtold@suse.com
- Fix Source
* Fri Mar 23 2018 tbechtold@suse.com
- update to 0.11.1:
  * Make workers admin command py3 safe
  * server: make stats more efficient
  * Add a send lock to the base Connection class
  * Server: support background jobs
  * Fix exception setter
  * Provide TextJob and TextWorker for convenience
  * Uncap pbr dependency
  * Update hacking dependency
  * Replace assertEquals with assertEqual
  * Make Job.name assume utf-8
  * Ignore E129
  * Move py27 after py34 and py35
  * Re-enable flake8
  * Add py35 to tox.ini default envs
  * Move other-requirements.txt to bindep.txt
  * Remove discover from test-requirements
  * Add test for AdminRequest.isComplete
  * Parse admin requests 2880 times faster
  * Geard: Handle connections closed while sending
  * Support TCP keepalives in geard
  * List system dependencies for running common tests
  * Do not encode the type (b) in the job name
  * Bump version requirement for pbr
  * Remove vestigal hook entry from setup.cfg
  * Remove py26 from tox.ini
  * Switch to six for configparser
  * Do not change object size when iterating
  * Allow setting a timeout for Client.waitForServer()
  * Remove shebang as the script is managed by an entry\_point
  * Guard against double shutdown in client
  * Remove argparse from requirements
  * Deprecated tox -downloadcache option removed
  * Add a test for worker termination
- Switch to singlespec
* Mon Dec  7 2015 tbechtold@suse.com
- Initial packaging (version 0.5.8)
